@@ -41,7 +41,14 @@
 #include <chrono>
 #include <memory>
 
-#include <openssl/ssl.h>
+#include "ssl_compat.h"
+
+#ifdef NGHTTP2_OPENSSL_IS_WOLFSSL
+#  include <wolfssl/options.h>
+#  include <wolfssl/openssl/ssl.h>
+#else // !NGHTTP2_OPENSSL_IS_WOLFSSL
+#  include <openssl/ssl.h>
+#endif // !NGHTTP2_OPENSSL_IS_WOLFSSL
 
 #include <ev.h>
 
@@ -65,7 +72,7 @@ struct Config {
 
   Headers headers;
   Headers trailer;
-  std::vector<int32_t> weight;
+  std::vector<nghttp2_extpri> extpris;
   std::string certfile;
   std::string keyfile;
   std::string datafile;
@@ -93,13 +100,11 @@ struct Config {
   bool upgrade;
   bool continuation;
   bool no_content_length;
-  bool no_dep;
   bool hexdump;
   bool no_push;
   bool expect_continue;
   bool verify_peer;
   bool ktls;
-  bool no_rfc7540_pri;
 };
 
 enum class RequestState { INITIAL, ON_REQUEST, ON_RESPONSE, ON_COMPLETE };
@@ -137,9 +142,9 @@ struct ContinueTimer {
 
 struct Request {
   // For pushed request, |uri| is empty and |u| is zero-cleared.
-  Request(const std::string &uri, const http_parser_url &u,
+  Request(const std::string &uri, const urlparse_url &u,
           const nghttp2_data_provider2 *data_prd, int64_t data_length,
-          const nghttp2_priority_spec &pri_spec, int level = 0);
+          const nghttp2_extpri &extpri, int level = 0);
   ~Request();
 
   void init_inflater();
@@ -172,8 +177,8 @@ struct Request {
   std::string method;
   // URI without fragment
   std::string uri;
-  http_parser_url u;
-  nghttp2_priority_spec pri_spec;
+  urlparse_url u;
+  nghttp2_extpri extpri;
   RequestTiming timing;
   int64_t data_length;
   int64_t data_offset;
@@ -248,7 +253,7 @@ struct HttpClient {
   void update_hostport();
   bool add_request(const std::string &uri,
                    const nghttp2_data_provider2 *data_prd, int64_t data_length,
-                   const nghttp2_priority_spec &pri_spec, int level = 0);
+                   const nghttp2_extpri &extpri, int level = 0);
 
   void record_start_time();
   void record_domain_lookup_end_time();
